@@ -366,6 +366,10 @@ read_NPX_explore <- function(filename) {
     out <- out %>% dplyr::mutate(dplyr::across(dplyr::all_of(matching_cols), as.logical))
   }
 
+  # PC Lot factor checks
+  check_darid(out)
+
+
 
   return(out)
 
@@ -823,3 +827,51 @@ check_data_completeness <- function(df){
   }
 
 }
+
+
+
+
+#' Check DarIDs
+#' DarIDs D.07, 08, 10, and 14 need to be exported with
+#' Panel Data Archive Version 1.5 or later
+#' @param df NPX data
+#'
+#' @return warning messages
+#'
+#' @keywords internal
+check_darid <- function(df){
+  if (all(c("PanelDataArchiveVersion", "DataAnalysisRefID") %in% names(df)) &&
+      any(stringr::str_detect(df[["DataAnalysisRefID"]],
+                              "D.*0007 || D.*0008 || D.*0010 || D.*0014")) &&
+      any(sapply(df[["PanelDataArchiveVersion"]], function(x){
+        utils::compareVersion("1.5", x)
+      }) == 1)){
+    cli::cli_alert_info(
+      paste0("Outdated Data Analysis Reference ID and ",
+             "Panel Archive Version combination detected."))
+    cli::cli_alert(
+      paste0("Re-export data using Panel Archive Version 1.5.0+ and",
+             "use the newest version of the Fixed LOD file ",
+             "when calculating LOD (Version 6+)."))
+    cli::cli_alert_warning(
+      paste0("Failure to re-export may result in ",
+             "incorrect PC normalization across lots and Fixed LOD ",
+             "calculations."))
+  }
+
+  if(all(c("ExploreVersion", "DataAnalysisRefID") %in% names(df)) &&
+     any(stringr::str_detect(df[["DataAnalysisRefID"]],
+                             "D.*0007 || D.*0008 || D.*0010 || D.*0014"))){
+    cli::cli_alert_info(
+      paste0("Outdated Data Analysis Reference ID and ",
+             "Software Version combination detected."))
+    cli::cli_alert(
+      paste0("Re-export data using Panel Archive Version 1.5.0+ in NPX Map and",
+             " use the newest version of the Fixed LOD file ",
+             "when calculating LOD (Version 6+)."))
+    cli::cli_alert_warning(
+      paste0("Failure to re-export may result in ",
+             "incorrect PC normalization across lots and Fixed LOD ",
+             "calculations."))
+  }
+}
