@@ -47,8 +47,8 @@ npxCheck <- function(df) {
 
   # Check for duplicates in SampleID ----
   duplicate_ids <- df |>
-    dplyr::select(SampleID,
-                  OlinkID) |>
+    dplyr::filter(!is.na(UniProt)) |>
+    dplyr::select(SampleID, OlinkID) |>
     duplicated()
 
   # Check if any duplicates are found
