@@ -23,6 +23,11 @@ test_that("olink_dist_plot works - vdiffr", {
   skip_on_cran()
   skip_if_not_installed("vdiffr")
 
-  vdiffr::expect_doppelganger('Distribution plot', distribution_plot)
-  vdiffr::expect_doppelganger('Distribution plot col by treatment', distribution_plot_treatColor)
+  distribution_plot_name <- "Distribution plot"
+  check_snap_exist(test_dir_name = "dist_plot", snap_name = distribution_plot_name)
+  vdiffr::expect_doppelganger(distribution_plot_name, distribution_plot)
+
+  distribution_plot_treatColor_name <- 'Distribution plot col by treatment'
+  check_snap_exist(test_dir_name = "dist_plot", snap_name = distribution_plot_treatColor_name)
+  vdiffr::expect_doppelganger(distribution_plot_treatColor_name, distribution_plot_treatColor)
 })
