@@ -247,7 +247,8 @@ test_that(
             ref_cols = norm_input_check$ref_cols,
             not_ref_cols = norm_input_check$not_ref_cols,
             bridge_samples = bridge_samples,
-            ref_product = norm_input_check$ref_product
+            prod_uniq = c(norm_input_check$not_ref_product,
+                          norm_input_check$ref_product)
           )
         )
       )
@@ -259,9 +260,10 @@ test_that(
           object = qs_norm_reveal <- olink_normalization_qs(
             lst_df = lst_df_reveal,
             ref_cols = norm_input_check_reveal$ref_cols,
-            not_ref_cols = norm_input_check$not_ref_cols,
+            not_ref_cols = norm_input_check_reveal$not_ref_cols,
             bridge_samples = bridge_samples_reveal,
-            ref_product = norm_input_check$ref_product
+            prod_uniq = c(norm_input_check_reveal$not_ref_product,
+                          norm_input_check_reveal$ref_product)
           )
         )
       )
@@ -273,9 +275,9 @@ test_that(
         ref_cols = norm_input_check$ref_cols,
         not_ref_cols = norm_input_check$not_ref_cols,
         bridge_samples = bridge_samples,
-        ref_product = "other"
+        prod_uniq = "other"
       ),
-      regexp = "Reference product must be HT or Reveal"
+      regexp = "Cross product bridging is only supported in the following cases"
     )
 
     # check if reference is reproduced ----
@@ -382,7 +384,8 @@ test_that(
             ref_cols = norm_input_check$ref_cols,
             not_ref_cols = norm_input_check$not_ref_cols,
             bridge_samples = bridge_samples,
-            ref_product = norm_input_check$ref_product
+            prod_uniq = c(norm_input_check$not_ref_product,
+                          norm_input_check$ref_product)
           )
         )
       )
@@ -510,7 +513,8 @@ test_that(
             ref_cols = norm_input_check$ref_cols,
             not_ref_cols = norm_input_check$not_ref_cols,
             bridge_samples = bridge_samples,
-            ref_product = norm_input_check$ref_product
+            prod_uniq = c(norm_input_check$not_ref_product,
+                          norm_input_check$ref_product)
           )
         )
       )
@@ -586,6 +590,8 @@ test_that(
   }
 )
 
+
+
 test_that(
   "olink_normalization_qs - works - fewer than 40 bridge samples",
   {
@@ -637,7 +643,8 @@ test_that(
         ref_cols = norm_input_check$ref_cols,
         not_ref_cols = norm_input_check$not_ref_cols,
         bridge_samples = head(x = bridge_samples, 38L),
-        ref_product = norm_input_check$ref_product
+        prod_uniq = c(norm_input_check$not_ref_product,
+                      norm_input_check$ref_product)
       ),
       regexp = "There are 104 assays with fewer than 40 bridge samples for QS"
     )
@@ -648,13 +655,299 @@ test_that(
         ref_cols = norm_input_check$ref_cols,
         not_ref_cols = norm_input_check$not_ref_cols,
         bridge_samples = head(x = bridge_samples, 40L),
-        ref_product = norm_input_check$ref_product
+        prod_uniq = c(norm_input_check$not_ref_product,
+                      norm_input_check$ref_product)
       ),
       regexp = "There are 31 assays with fewer than 40 bridge samples for QS"
     )
   }
 )
 
+test_that(
+  "olink_normalization_qs - works - fewer than 40 bridge samples, some NA",
+  {
+
+    skip_if_not(file.exists(test_path("data", "example_3k_data.rds")))
+    skip_if_not(file.exists(test_path("data", "example_HT_data.rds")))
+
+    data_3k <- get_example_data(filename = "example_3k_data.rds")
+    data_ht <- get_example_data(filename = "example_HT_data.rds")
+
+    # 40 bridge samples for all assays ----
+
+    bridge_samples <- intersect(
+      x = unique(data_ht$SampleID),
+      y = unique(data_3k$SampleID)
+    ) |>
+      (\(x) x[!grepl("CONTROL", x)])() |>
+      sort()
+
+    # run the internal function that check input from olink_normalization
+    expect_warning(
+      object = expect_message(
+        object = norm_input_check <- olink_norm_input_check(
+          df1 = data_ht,
+          df2 = data_3k,
+          overlapping_samples_df1 = head(x = bridge_samples, 40L),
+          overlapping_samples_df2 = NULL,
+          df1_project_nr = "P1",
+          df2_project_nr = "P2",
+          reference_project = "P1",
+          reference_medians = NULL
+        ),
+        regexp = "Cross-product normalization will be performed!"
+      ),
+      regexp = "2 assays are not shared across products."
+    )
+
+    lst_df <- list(
+      norm_input_check$ref_df,
+      norm_input_check$not_ref_df
+    )
+    names(lst_df) <- c(norm_input_check$ref_name,
+                       norm_input_check$not_ref_name)
+
+    # run the function
+    expect_warning(
+      object = norm_qs_40_bridge <- olink_normalization_qs(
+        lst_df = lst_df,
+        ref_cols = norm_input_check$ref_cols,
+        not_ref_cols = norm_input_check$not_ref_cols,
+        bridge_samples = head(x = bridge_samples, 40L),
+        prod_uniq = c(norm_input_check$not_ref_product,
+                      norm_input_check$ref_product)
+      ),
+      regexp = "There are 31 assays with fewer than 40 bridge samples for QS"
+    )
+
+    # select assays for which we introduce NAs
+    norm_qs_oid_na <- norm_qs_40_bridge |>
+      tidyr::drop_na() |>
+      dplyr::pull(
+        .data[["OlinkID"]]
+      ) |>
+      head(
+        n = 2L
+      )
+    norm_qs_oid_ht_na <- stringr::str_split(
+      string = norm_qs_oid_na,
+      pattern = "_"
+    ) |>
+      lapply(head, 1L) |>
+      unlist()
+    norm_qs_oid_3k_na <- stringr::str_split(
+      string = norm_qs_oid_na,
+      pattern = "_"
+    ) |>
+      lapply(tail, 1L) |>
+      unlist()
+
+    ## introduce NAs in HT bridge samples for some assays that are not NA ----
+
+    data_ht_v2 <- data_ht |>
+      dplyr::mutate(
+        NPX = dplyr::if_else(
+          .data[["SampleID"]] == bridge_samples[1L]
+          & .data[["OlinkID"]] %in% .env[["norm_qs_oid_ht_na"]],
+          NA_real_,
+          .data[["NPX"]]
+        )
+      )
+
+    # run the internal function that check input from olink_normalization
+    expect_warning(
+      object = expect_message(
+        object = norm_input_check_ht <- olink_norm_input_check(
+          df1 = data_ht_v2,
+          df2 = data_3k,
+          overlapping_samples_df1 = head(x = bridge_samples, 40L),
+          overlapping_samples_df2 = NULL,
+          df1_project_nr = "P1",
+          df2_project_nr = "P2",
+          reference_project = "P1",
+          reference_medians = NULL
+        ),
+        regexp = "Cross-product normalization will be performed!"
+      ),
+      regexp = "2 assays are not shared across products."
+    )
+
+    lst_df <- list(
+      norm_input_check_ht$ref_df,
+      norm_input_check_ht$not_ref_df
+    )
+    names(lst_df) <- c(norm_input_check_ht$ref_name,
+                       norm_input_check_ht$not_ref_name)
+
+    # run the function
+    expect_warning(
+      object = norm_qs_ht_na <-
+        olink_normalization_qs(lst_df = lst_df,
+                               ref_cols = norm_input_check_ht$ref_cols,
+                               not_ref_cols = norm_input_check_ht$not_ref_cols,
+                               bridge_samples = head(x = bridge_samples, 40L),
+                               prod_uniq = c(
+                                 norm_input_check_ht$not_ref_product,
+                                 norm_input_check_ht$ref_product
+                               )),
+      regexp = "There are 33 assays with fewer than 40 bridge samples for QS"
+    )
+
+    expect_true(
+      object = norm_qs_ht_na |>
+        dplyr::filter(
+          .data[["Project"]] == norm_input_check_ht$not_ref_name
+          & .data[["OlinkID"]] %in% .env[["norm_qs_oid_na"]]
+        ) |>
+        dplyr::pull(
+          .data[["QSNormalizedNPX"]]
+        ) |>
+        is.na() |>
+        all()
+    )
+
+    ## introduce NAs in 3k bridge samples for some assays that are not NA ----
+
+    data_3k_v2 <- data_3k |>
+      dplyr::mutate(
+        NPX = dplyr::if_else(
+          .data[["SampleID"]] %in% bridge_samples[1L:3L]
+          & .data[["OlinkID"]] %in% .env[["norm_qs_oid_3k_na"]],
+          NA_real_,
+          .data[["NPX"]]
+        )
+      )
+
+    # run the internal function that check input from olink_normalization
+    expect_warning(
+      object = expect_message(
+        object = norm_input_check_3k <- olink_norm_input_check(
+          df1 = data_ht,
+          df2 = data_3k_v2,
+          overlapping_samples_df1 = head(x = bridge_samples, 40L),
+          overlapping_samples_df2 = NULL,
+          df1_project_nr = "P1",
+          df2_project_nr = "P2",
+          reference_project = "P1",
+          reference_medians = NULL
+        ),
+        regexp = "Cross-product normalization will be performed!"
+      ),
+      regexp = "2 assays are not shared across products."
+    )
+
+    lst_df <- list(
+      norm_input_check_3k$ref_df,
+      norm_input_check_3k$not_ref_df
+    )
+    names(lst_df) <- c(norm_input_check_3k$ref_name,
+                       norm_input_check_3k$not_ref_name)
+
+    # run the function
+    expect_warning(
+      object = norm_qs_3k_na <- olink_normalization_qs(
+        lst_df = lst_df,
+        ref_cols = norm_input_check_3k$ref_cols,
+        not_ref_cols = norm_input_check_3k$not_ref_cols,
+        bridge_samples = head(x = bridge_samples, 40L),
+        prod_uniq = c(
+          norm_input_check_3k$not_ref_product,
+          norm_input_check_3k$ref_product
+        )
+      ),
+      regexp = "There are 33 assays with fewer than 40 bridge samples for QS"
+    )
+
+    expect_true(
+      object = norm_qs_3k_na |>
+        dplyr::filter(
+          .data[["Project"]] == norm_input_check_3k$not_ref_name
+          & .data[["OlinkID"]] %in% .env[["norm_qs_oid_na"]]
+        ) |>
+        dplyr::pull(
+          .data[["QSNormalizedNPX"]]
+        ) |>
+        is.na() |>
+        all()
+    )
+  }
+)
+
+
+test_that(
+  "olink_normalization_qs - works - HT/Reveal",
+  {
+
+    skip_if_not(file.exists(test_path("data", "example_HT_data.rds")))
+    skip_if_not(file.exists(test_path("data", "example_Reveal_data.rds")))
+
+    data_ht <- get_example_data(filename = "example_HT_data.rds")
+    data_reveal <- get_example_data(filename = "example_Reveal_data.rds") |>
+      # Set unique OlinkID for TEST_Reveal assay
+      dplyr::mutate(OlinkID = ifelse(.data[["Assay"]] == "TEST_Reveal",
+                                     "OID56789",
+                                     OlinkID))
+
+
+    bridge_samples <- intersect(
+      x = unique(data_ht$SampleID),
+      y = unique(data_reveal$SampleID)
+    ) |>
+      (\(x) x[!grepl("CONTROL", x)])() |>
+      sort()
+
+    # run the internal function that check input from olink_normalization
+    expect_warning(
+      object = expect_message(
+        object = norm_input_check <- olink_norm_input_check(
+          df1 = data_ht,
+          df2 = data_reveal,
+          overlapping_samples_df1 = bridge_samples,
+          overlapping_samples_df2 = NULL,
+          df1_project_nr = "P1",
+          df2_project_nr = "P2",
+          reference_project = "P1",
+          reference_medians = NULL
+        ),
+        regexp = "Cross-product normalization will be performed!"
+      ),
+      regexp = "82 assays are not shared across products."
+    )
+
+    lst_df <- list(
+      norm_input_check$ref_df,
+      norm_input_check$not_ref_df
+    )
+    names(lst_df) <- c(norm_input_check$ref_name,
+                       norm_input_check$not_ref_name)
+
+    # > 24 bridge samples included, no QS warning ----
+    expect_no_warning(
+      object = olink_normalization_qs(
+        lst_df = lst_df,
+        ref_cols = norm_input_check$ref_cols,
+        not_ref_cols = norm_input_check$not_ref_cols,
+        bridge_samples = bridge_samples,
+        prod_uniq = c(norm_input_check$not_ref_product,
+                      norm_input_check$ref_product)
+      )
+    )
+
+    # < 24 samples included, QS warning ----
+    expect_warning(
+      object = olink_normalization_qs(
+        lst_df = lst_df,
+        ref_cols = norm_input_check$ref_cols,
+        not_ref_cols = norm_input_check$not_ref_cols,
+        bridge_samples = head(x = bridge_samples, 18L),
+        prod_uniq = c(norm_input_check$not_ref_product,
+                      norm_input_check$ref_product)
+      ),
+      regexp = "There are 21 assays with fewer than 24 bridge samples for QS"
+    )
+  }
+)
+
 # Test olink_normalization_product_format ----
 
 test_that(
@@ -672,6 +965,23 @@ test_that(
     ) |>
       (\(x) x[!grepl("CONTROL", x)])()
 
+    expect_warning(
+      object = expect_message(
+        lst_check_3k_ht <- olink_norm_input_check(
+          df1 = data_3k,
+          df2 = data_ht,
+          overlapping_samples_df1 = bridge_samples_3k_ht,
+          overlapping_samples_df2 = NULL,
+          df1_project_nr = "P1",
+          df2_project_nr = "P2",
+          reference_project = "P2",
+          reference_medians = NULL
+        ),
+        regexp = "Cross-product normalization will be performed!"
+      ),
+      regexp = "2 assays are not shared across products."
+    )
+
     # formatted data
     expect_message(
       object = expect_warning(
@@ -712,8 +1022,8 @@ test_that(
         df1_project_nr = "P2",
         df2 = data_3k,
         df2_project_nr = "P1",
-        reference_project = "P2",
-        ref_product = "HT"
+        lst_check = lst_check_3k_ht,
+        prod_uniq = c("3k", "HT")
       )
     )
 
@@ -840,8 +1150,6 @@ test_that(
     data_3k <- get_example_data(filename = "example_3k_data.rds")
     data_reveal <- get_example_data(filename = "example_Reveal_data.rds")
 
-    # 3k-HT ----
-
     bridge_samples_3k_reveal <- intersect(
       x = unique(data_3k$SampleID),
       y = unique(data_reveal$SampleID)
@@ -850,6 +1158,23 @@ test_that(
       sort() |>
       head(35L)
 
+    expect_warning(
+      object = expect_message(
+        lst_check_3k_reveal <- olink_norm_input_check(
+          df1 = data_3k,
+          df2 = data_reveal,
+          overlapping_samples_df1 = bridge_samples_3k_reveal,
+          overlapping_samples_df2 = NULL,
+          df1_project_nr = "P1",
+          df2_project_nr = "P2",
+          reference_project = "P2",
+          reference_medians = NULL
+        ),
+        regexp = "Cross-product normalization will be performed!"
+      ),
+      regexp = "85 assays are not shared across products."
+    )
+
     # formatted data
     expect_warning(
       object = expect_warning(
@@ -896,8 +1221,8 @@ test_that(
         df1_project_nr = "P2",
         df2 = data_3k,
         df2_project_nr = "P1",
-        reference_project = "P2",
-        ref_product = "Reveal"
+        lst_check = lst_check_3k_reveal,
+        prod_uniq = c("3k", "Reveal")
       )
     )
 
